@@ -11,18 +11,18 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.9.6-MariaDB"
+#define MYSQL_SERVER_VERSION		"10.9.8-MariaDB"
 #define MYSQL_BASE_VERSION		"mysqld-10.9"
 #define MARIADB_BASE_VERSION		"mariadb-10.9"
 #define MARIADBD_BASE_VERSION		"mariadbd-10.9"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100906
+#define MYSQL_VERSION_ID		100908
 #define MARIADB_PORT                    3306
 #define MYSQL_PORT_DEFAULT		0
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mariadb-server-10.9.6v1"
+#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mariadb-server-10.9.8p1v1"
 #define SERVER_MATURITY_LEVEL           MariaDB_PLUGIN_MATURITY_STABLE
 
 #define MYSQL_PORT                      MARIADB_PORT
