@@ -395,8 +395,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "aarch64"
-#define DEFAULT_MACHINE "aarch64"
+#define MACHINE_TYPE "riscv64"
+#define DEFAULT_MACHINE "riscv64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -531,16 +531,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 9
-#define MYSQL_VERSION_PATCH 6
+#define MYSQL_VERSION_PATCH 8
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.9.6"
+#define PACKAGE_STRING "MySQL Server 10.9.8"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.9.6"
-#define VERSION "10.9.6"
+#define PACKAGE_VERSION "10.9.8"
+#define VERSION "10.9.8"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
