@@ -800,6 +800,7 @@ public:
   bool select_transformer(JOIN *join);
   void create_comp_func(bool invert) { func= func_creator(invert); }
   void print(String *str, enum_query_type query_type);
+  enum precedence precedence() const { return CMP_PRECEDENCE; }
   bool is_maxmin_applicable(JOIN *join);
   bool transform_into_max_min(JOIN *join);
   void no_rows_in_result();
@@ -830,7 +831,7 @@ public:
     item= si;
     maybe_null= 0;
   }
-  virtual ~subselect_engine() {}; // to satisfy compiler
+  virtual ~subselect_engine() = default;; // to satisfy compiler
   virtual void cleanup()= 0;
 
   /*
