@@ -353,7 +353,7 @@ public:
   /* See RANGE_OPT_PARAM::alloced_sel_args */
   enum { MAX_SEL_ARGS = 16000 };
 
-  SEL_ARG() {}
+  SEL_ARG() = default;
   SEL_ARG(SEL_ARG &);
   SEL_ARG(Field *, const uchar *, const uchar *);
   SEL_ARG(Field *field, uint8 part,
@@ -955,7 +955,7 @@ class QUICK_RANGE :public Sql_alloc {
     }
 
   /**
-     Initalizes a key_range object for communication with storage engine. 
+     Initializes a key_range object for communication with storage engine. 
 
      This function facilitates communication with the Storage Engine API by
      translating the minimum endpoint of the interval represented by this
@@ -976,7 +976,7 @@ class QUICK_RANGE :public Sql_alloc {
   }
   
   /**
-     Initalizes a key_range object for communication with storage engine. 
+     Initializes a key_range object for communication with storage engine. 
 
      This function facilitates communication with the Storage Engine API by
      translating the minimum endpoint of the interval represented by this
@@ -993,7 +993,7 @@ class QUICK_RANGE :public Sql_alloc {
   }
 
   /**
-     Initalizes a key_range object for communication with storage engine. 
+     Initializes a key_range object for communication with storage engine. 
 
      This function facilitates communication with the Storage Engine API by
      translating the maximum endpoint of the interval represented by this
@@ -1014,7 +1014,7 @@ class QUICK_RANGE :public Sql_alloc {
   }
 
   /**
-     Initalizes a key_range object for communication with storage engine. 
+     Initializes a key_range object for communication with storage engine. 
 
      This function facilitates communication with the Storage Engine API by
      translating the maximum endpoint of the interval represented by this
@@ -1110,7 +1110,7 @@ public:
   uint used_key_parts;
 
   QUICK_SELECT_I();
-  virtual ~QUICK_SELECT_I(){};
+  virtual ~QUICK_SELECT_I() = default;;
 
   /*
     Do post-constructor initialization.
