@@ -905,6 +905,11 @@ public:
   }
   Item *make_item_func_trim_std(THD *thd) const;
   Item *make_item_func_trim_oracle(THD *thd) const;
+  /*
+    This method is still used to handle LTRIM and RTRIM,
+    while the special syntax TRIM(... BOTH|LEADING|TRAILING)
+    is now handled by Schema::make_item_func_trim().
+  */
   Item *make_item_func_trim(THD *thd) const;
 };
 
@@ -916,6 +921,25 @@ public:
 };
 
 
+class Lex_substring_spec_st
+{
+public:
+  Item *m_subject;
+  Item *m_from;
+  Item *m_for;
+  static Lex_substring_spec_st init(Item *subject,
+                                    Item *from,
+                                    Item *xfor= NULL)
+  {
+    Lex_substring_spec_st res;
+    res.m_subject= subject;
+    res.m_from= from;
+    res.m_for= xfor;
+    return res;
+  }
+};
+
+
 class st_select_lex;
 
 class Lex_select_lock
@@ -983,7 +1007,7 @@ public:
 class Load_data_outvar
 {
 public:
-  virtual ~Load_data_outvar() {}
+  virtual ~Load_data_outvar() = default;
   virtual bool load_data_set_null(THD *thd, const Load_data_param *param)= 0;
   virtual bool load_data_set_value(THD *thd, const char *pos, uint length,
                                    const Load_data_param *param)= 0;
@@ -997,7 +1021,7 @@ public:
 class Timeval: public timeval
 {
 protected:
-  Timeval() { }
+  Timeval() = default;
 public:
   Timeval(my_time_t sec, ulong usec)
   {
